@@ -18,6 +18,19 @@ class BaseDataset(ABC):
         """
         raise NotImplementedError()
 
+    @abstractclassmethod
+    def get_validation_dataset(cls, **kwargs)->(tf.data.Dataset, int):
+        """Validation用のデータセットを取得する
+        
+        Arguments:
+            cls -- クラスオブジェクト
+        
+        Returns:
+            データセットとデータセットのサイズを持ったタプル
+        """
+        raise NotImplementedError()
+
+
     @abstractclassmethod
     def get_test_dataset(cls, **kwargs)->(tf.data.Dataset, int):
         """テスト用のデータセットを取得する
@@ -29,3 +42,5 @@ class BaseDataset(ABC):
             データセットとデータセットのサイズを持ったタプル
         """
         raise NotImplementedError()
+
+
