@@ -33,7 +33,8 @@ class ResumeExecutor():
         return cls.instance
     
     def _load_values(self)->(int,float,bool):
-        f = tf.io.gfile.GFile(self._get_resume_path(),mode="r")
+        rp = self._get_resume_path()
+        f = tf.io.gfile.GFile(rp,mode="r")
         s = f.read()
         splited = s.split(",")
         epoch = int(splited[0])
@@ -46,13 +47,20 @@ class ResumeExecutor():
         return ret
 
     def is_train_ended(self)->bool:
-        if tf.io.gfile.exists(self.path) == True:
+        context = Context.get_instance()
+        if context[Context.SUSPEND_RESUME] == False:
+            return False
+        if tf.io.gfile.exists(self._get_model_path()) == True:
             _, _, _, end =self._load_values()
             return end
         else:
             return False
     
     def is_resumable_training(self)->bool:
+        context = Context.get_instance()
+        if context[Context.SUSPEND_RESUME] == False:
+            return False
+
         if tf.io.gfile.exists(self._get_model_path()):
             return not self.is_train_ended()
         else:
@@ -76,7 +84,6 @@ class ResumeExecutor():
         model.load_weights(self._get_model_path())
 
     def suspend(self,epoch,lr,best,model):
-        print("\nSusupend!!!")
         self._check_dir()
         file = self._get_resume_path()
         f = tf.io.gfile.GFile(file, mode="w")
